@@ -16,7 +16,7 @@ def get_default_logging_conf(log_level: str, formatter: str, own_apps: list[str]
         },
         "plain_console": {
             "()": structlog.stdlib.ProcessorFormatter,
-            "processor": structlog.dev.ConsoleRenderer(),
+            "processor": structlog.dev.ConsoleRenderer(event_key='message'),
         },
         "key_value": {
             "()": structlog.stdlib.ProcessorFormatter,
