@@ -34,9 +34,9 @@ class LoggingConfigurator:
         """
         record = event_dict.get("_record")
         if record is None:
-            event_dict["logger"] = logger.name
+            event_dict["name"] = logger.name
         else:
-            event_dict["logger"] = record.name
+            event_dict["name"] = record.name
         return event_dict
 
     def get_processors(self) -> list:
